@@ -142,15 +142,19 @@ def find_binaries(path_to_find_bin, output_dir, format, dburl=""):
     content_list = []
     result_file = ""
 
+    if not os.path.isdir(path_to_find_bin):
+        error_occured(error_msg=f"Can't find the directory : {path_to_find_bin}",
+                      result_log=_result_log,
+                      exit=True)
     try:
-        if not os.path.isdir(path_to_find_bin):
-            error_occured(error_msg=f"Can't find the directory : {path_to_find_bin}",
-                          result_log=_result_log,
-                          exit=True)
-
         total_file_cnt, file_list, found_jar = get_file_list(path_to_find_bin)
-        total_bin_cnt, return_list = return_bin_only(file_list)
-
+        return_list = list(return_bin_only(file_list))
+    except Exception as ex:
+        error_occured(error_msg=f"Failed to check whether it is binary or not : {ex}",
+                      result_log=_result_log,
+                      exit=True)
+    total_bin_cnt = len(return_list)
+    try:
         # Run OWASP Dependency-check
         if found_jar:
             logger.info("Run OWASP Dependency-check to analyze .jar file")
@@ -164,9 +168,9 @@ def find_binaries(path_to_find_bin, output_dir, format, dburl=""):
         return_list, db_loaded_cnt = get_oss_info_from_db(return_list, dburl)
         return_list = sorted(return_list, key=lambda row: (row.bin_name))
 
-        _str_files = [x.get_print_binary_only() for x in return_list]
+        str_files = (x.get_print_binary_only() for x in return_list)
         success, error = write_txt_file(binary_txt_file,
-                                        "Binary\tsha1sum\ttlsh\n" + '\n'.join(_str_files))
+                                        "Binary\tsha1sum\ttlsh\n" + '\n'.join(str_files))
 
         if success:
             _result_log["FOSSLight binary.txt"] = binary_txt_file
@@ -174,15 +178,13 @@ def find_binaries(path_to_find_bin, output_dir, format, dburl=""):
             error_occured(error_msg=error, exit=False)
 
         sheet_list = {}
-        for scan_item in return_list:
-            content_list.extend(scan_item.get_oss_report())
+        content_list = [list(item.get_oss_report()) for item in return_list]
         sheet_list["BIN_FL_Binary"] = content_list
 
         success_to_write, writing_msg, result_file = write_output_file(result_report, output_extension, sheet_list, extended_header)
     except Exception as ex:
         error_occured(error_msg=str(ex), exit=False)
 
-    # Print Result
     try:
         if success_to_write:
             logger.info(f"Output file :{result_file}")
@@ -200,8 +202,6 @@ def find_binaries(path_to_find_bin, output_dir, format, dburl=""):
 
 
 def return_bin_only(file_list):
-    bin_cnt = 0
-    bin_list = []
     for file_item in file_list:
         file_with_path = file_item.bin_name
         file = file_item.binary_name_without_path
@@ -211,7 +211,11 @@ def return_bin_only(file_list):
             if stat.S_ISFIFO(os.stat(file_with_path).st_mode):
                 continue
             if is_binary(file_with_path):
-                file_command_result = magic.from_file(file_with_path)
+                file_command_result = ""
+                try:
+                    file_command_result = magic.from_file(file_with_path)
+                except Exception as ex:
+                    logger.debug(f"Failed to check specific file type:{file_with_path}, {ex}")
                 if file_command_result != "":
                     file_command_result = file_command_result.lower()
                     removed_keyword = [x for x in _REMOVE_FILE_COMMAND_RESULT if
@@ -223,10 +227,7 @@ def return_bin_only(file_list):
                 if error:
                     error_occured(error_msg=error_msg, exit=False)
 
-                bin_list.append(file_item)
-                bin_cnt += 1
-
-    return bin_cnt, bin_list
+                yield file_item
 
 
 def error_occured(error_msg, exit=False, result_log={}):
